Stan Math Library: stan::math::container_view< std::vector< T1 >, T2 > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | List of all members
stan::math::container_view< std::vector< T1 >, T2 > Class Template Reference

Template specialization for scalar view of array y with scalar type T2 with proper indexing inferred from input vector x of scalar type T1. More...

`#include <container_view.hpp>`

## Public Member Functions
| container_view (const std::vector< T1 > &x, T2 *y)
| Constructor. More...
T2 & | operator[] (int i)
| operator[](int i) returns reference to scalar view indexed at i More...

## Detailed Description

### template<typename T1, typename T2>
class stan::math::container_view< std::vector< T1 >, T2 >

Template specialization for scalar view of array y with scalar type T2 with proper indexing inferred from input vector x of scalar type T1.

Template Parameters

  T1 | scalar type of input vector
  T2 | scalar type returned by view.

Definition at line 20 of file container_view.hpp.

## Constructor & Destructor Documentation

template<typename T1 , typename T2 >

stan::math::container_view< std::vector< T1 >, T2 >::container_view | ( | const std::vector< T1 > & | x,
|  | T2 * | y
| ) |  |
| inline

Constructor.

Parameters

  x | input vector
  y | underlying array

Definition at line 28 of file container_view.hpp.

## Member Function Documentation

template<typename T1 , typename T2 >

T2& stan::math::container_view< std::vector< T1 >, T2 >::operator[] | ( | int | i | ) |
| inline

operator[](int i) returns reference to scalar view indexed at i

Parameters

  i | index of scalar element

Definition at line 37 of file container_view.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/arr/meta/container_view.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.